import {
  select,
  range,
  symbols,
  symbol,
} from 'd3';

const width = window.innerWidth;
const height = window.innerHeight;

// create a new SVG element and append it to the body of the document
// set width and height
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

// horizontal rectangles
const n = 100;
svg
  .selectAll('rect.horizontal') // select all rectangles on the page
  .data(range(n)) // create one rectangle for each mark
  .join('rect')
  .attr('y', (d) => d * 20) // function - value changes for each object
  .attr('width', width) // constant value
  .attr('height', 10)
  .attr('class', 'horizontal')
  .attr('mask', 'url(#mask-1)');

// vertical rectangles
svg
  .selectAll('rect.vertical') // select all rectangles on the page
  .data(range(n)) // create one rectangle for each mark
  .join('rect')
  .attr('x', (d) => d * 20) // function - value changes for each object
  .attr('width', 10) // constant value
  .attr('height', height)
  .attr('class', 'vertical')
  .attr('mask', 'url(#mask-2)');

const renderMask = (selection, id, inverted) => {
  // mask element
  const mask = selection
    .append('mask')
    .attr('id', id);

  // rectangle mask
  mask
    .append('rect')
    .attr('width', width)
    .attr('height', height)
    .attr('fill', inverted ? 'white' : 'black');

  // circle mask
  // mask
  //   .append('g') // shape is initially centered at 0,0; use group element to move the shape around
  //   .attr(
  //     'transform',
  //     `translate(${width / 2}, ${height / 2})`
  //   ) // `: string template literals
  //   .append('path')
  //   .attr('d', symbol(symbols[0], 100000))
  //   .attr('fill', inverted ? 'black' : 'white');

  const g = mask
    .append('g') // shape is initially centered at 0,0; use group element to move the shape around
    .attr(
      'transform',
      `translate(${width / 2}, ${height / 2})`
    );
  mask
    .selectAll('g')
    .data(range(symbols.length))
    .join((enter) =>
      enter
        .append('g')
        .append('path')
        .attr('d', (d) => 
          symbol(symbols[d], 10000)())
        .attr('transform', (d) => `translate(${d * 125 + 100}, ${height / 2})`)
        .attr(
          'fill',
          inverted ? 'black' : 'white'
        )
    );
};

// renderMask(svg, 'mask-1', false); // does the same thing as the svg.call below
// renderMask(svg, 'mask-2', true);

svg
  .call(renderMask, 'mask-1', false)
  .call(renderMask, 'mask-2', true);
